@@ -1,10 +1,12 @@
+import inspect
 from typing import Dict, Optional, TYPE_CHECKING, Tuple, Type
 
 import pydantic
 from pydantic.fields import ModelField
 from pydantic.utils import lenient_issubclass
 
-from ormar.fields import BaseField  # noqa: I100, I202
+from ormar.exceptions import ModelDefinitionError  # noqa: I100, I202
+from ormar.fields import BaseField
 
 if TYPE_CHECKING:  # pragma no cover
     from ormar import Model
@@ -82,12 +84,43 @@ def populate_pydantic_default_values(attrs: Dict) -> Tuple[Dict, Dict]:
     for field_name, field in potential_fields.items():
         field.name = field_name
         model_fields[field_name] = field
-        attrs["__annotations__"][field_name] = (
+        default_type = (
             field.__type__ if not field.nullable else Optional[field.__type__]
         )
+        overwrite_type = (
+            field.__pydantic_type__
+            if field.__type__ != field.__pydantic_type__
+            else None
+        )
+        attrs["__annotations__"][field_name] = overwrite_type or default_type
     return attrs, model_fields
 
 
+def merge_or_generate_pydantic_config(attrs: Dict, name: str) -> None:
+    """
+    Checks if the user provided pydantic Config,
+    and if he did merges it with the default one.
+
+    Updates the attrs in place with a new config.
+
+    :rtype: None
+    """
+    DefaultConfig = get_pydantic_base_orm_config()
+    if "Config" in attrs:
+        ProvidedConfig = attrs["Config"]
+        if not inspect.isclass(ProvidedConfig):
+            raise ModelDefinitionError(
+                f"Config provided for class {name} has to be a class."
+            )
+
+        class Config(ProvidedConfig, DefaultConfig):  # type: ignore
+            pass
+
+        attrs["Config"] = Config
+    else:
+        attrs["Config"] = DefaultConfig
+
+
 def get_pydantic_base_orm_config() -> Type[pydantic.BaseConfig]:
     """
     Returns empty pydantic Config with orm_mode set to True.
