@@ -1,5 +1,6 @@
 from typing import (
     Callable,
+    Dict,
     List,
     Optional,
     Set,
@@ -20,6 +21,7 @@ class RelationMixin:
         from ormar import ModelMeta
 
         Meta: ModelMeta
+        __relation_map__: Optional[List[str]]
         _related_names: Optional[Set]
         _through_names: Optional[Set]
         _related_fields: Optional[List]
@@ -120,7 +122,11 @@ class RelationMixin:
 
     @classmethod
     def _iterate_related_models(  # noqa: CCR001
-        cls, node_list: NodeList = None, source_relation: str = None
+        cls,
+        node_list: NodeList = None,
+        parsed_map: Dict = None,
+        source_relation: str = None,
+        recurrent: bool = False,
     ) -> List[str]:
         """
         Iterates related models recursively to extract relation strings of
@@ -130,12 +136,15 @@ class RelationMixin:
         :rtype: List[str]
         """
         if not node_list:
+            if cls.__relation_map__:
+                return cls.__relation_map__
             node_list = NodeList()
+            parsed_map = dict()
             current_node = node_list.add(node_class=cls)
         else:
             current_node = node_list[-1]
-        relations = cls.extract_related_names()
-        processed_relations = []
+        relations = sorted(cls.extract_related_names())
+        processed_relations: List[str] = []
         for relation in relations:
             if not current_node.visited(relation):
                 target_model = cls.Meta.model_fields[relation].to
@@ -144,12 +153,23 @@ class RelationMixin:
                     relation_name=relation,
                     parent_node=current_node,
                 )
-                deep_relations = target_model._iterate_related_models(
-                    source_relation=relation, node_list=node_list
-                )
+                relation_key = f"{cls.get_name()}_{relation}"
+                parsed_map = cast(Dict, parsed_map)
+                deep_relations = parsed_map.get(relation_key)
+                if not deep_relations:
+                    deep_relations = target_model._iterate_related_models(
+                        source_relation=relation,
+                        node_list=node_list,
+                        recurrent=True,
+                        parsed_map=parsed_map,
+                    )
+                    parsed_map[relation_key] = deep_relations
                 processed_relations.extend(deep_relations)
 
-        return cls._get_final_relations(processed_relations, source_relation)
+        result = cls._get_final_relations(processed_relations, source_relation)
+        if not recurrent:
+            cls.__relation_map__ = result
+        return result
 
     @staticmethod
     def _get_final_relations(
